pub trait ModelUpdateController {
// Required methods
fn notify_audio_source_content_changed(
&mut self,
source: ARAAudioSourceRef,
content: *const c_void,
);
fn notify_model_update(&mut self);
fn notify_restored_from_archive(&mut self);
}Expand description
Host-side model update interface.
The plugin calls these methods to tell the DAW that model objects (audio sources, musical contexts, etc.) have changed.
Required Methods
Sourcefn notify_audio_source_content_changed(
&mut self,
source: ARAAudioSourceRef,
content: *const c_void,
)
fn notify_audio_source_content_changed( &mut self, source: ARAAudioSourceRef, content: *const c_void, )
Notify the host that an audio source’s content has changed.
Sourcefn notify_model_update(&mut self)
fn notify_model_update(&mut self)
Notify the host that new model objects are available.
Sourcefn notify_restored_from_archive(&mut self)
fn notify_restored_from_archive(&mut self)
Notify the host that the plugin session has been restored from archive.